/****************************************************************
Copyright (c) 1998 Sandro Sigala <ssigala@globalnet.it>.
All rights reserved.

Permission to use, copy, modify, and distribute this software
and its documentation for any purpose and without fee is hereby
granted, provided that the above copyright notice appear in all
copies and that both that the copyright notice and this
permission notice and warranty disclaimer appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

The author disclaim all warranties with regard to this
software, including all implied warranties of merchantability
and fitness.  In no event shall the author be liable for any
special, indirect or consequential damages or any damages
whatsoever resulting from loss of use, data or profits, whether
in an action of contract, negligence or other tortious action,
arising out of or in connection with the use or performance of
this software.
****************************************************************/

#ifndef GAMEWIDGET_H
#define GAMEWIDGET_H

#include <qwidget.h>

#include "krepton.h"
#include "map.h"

class QPixmap;

class GameWidget : public QWidget {
	Q_OBJECT

signals:
	void changedStats(int, int, int, bool);
	void gameOver();

public:
	bool in_game, in_pause;
	KAudio *audio;
	bool do_sounds;
	Map *current_map;

	GameWidget(QWidget *parent=0, const char *name=0);
	void loadEpisode(const QString& path);
	void loadSprites(const QString& path);
	void loadMaps(const QString& path);
	void startGame(const QString& episode, int level, int points = 0);
	void startGamePassword(const QString& episode, const QString& password);

private:
	QPixmap *sprites;
	Map *maps;
	int current_level;
	int num_levels;
	int timerObjects, timerMonsters, timerEggs;
	int timerSecs, timerPlants;
	QString episode_name;

public slots:
	void goUp();
        void goDown();
	void goLeft();
	void goRight();

protected:
	void timerEvent(QTimerEvent *e);
	void paintEvent(QPaintEvent *);
};

#endif // !GAMEWIDGET_H
